@@ -1,10 +1,10 @@
 -- Samizdat Database Creation - PostgreSQL
 --
---   Copyright (c) 2002-2006  Dmitry Borodaenko <angdraug@debian.org>
+--   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 --
 --   This program is free software.
 --   You can distribute/modify this program under the terms of
---   the GNU General Public License version 2 or later.
+--   the GNU General Public License version 3 or later.
 --
 
 -- RDF Data Model
@@ -35,7 +35,7 @@ CREATE INDEX Statement_object_idx ON Statement (object);
 CREATE TABLE Member (
 	id INTEGER PRIMARY KEY REFERENCES Resource,
 	login TEXT UNIQUE NOT NULL,
-	full_name TEXT NOT NULL,
+	full_name TEXT,
 	email TEXT UNIQUE NOT NULL,
 	password TEXT,
 	prefs TEXT,
@@ -95,3 +95,10 @@ CREATE TABLE Possession (
 	item INTEGER REFERENCES Item,
 	taken_from INTEGER REFERENCES Member,
 	given_to INTEGER REFERENCES Member);
+
+-- Role-based Access Control
+CREATE TABLE Role (
+	member INTEGER REFERENCES Member,
+	role TEXT);
+
+CREATE INDEX Role_member_idx ON Role (member);
