@@ -1,15 +1,15 @@
 # Samizdat engine environment setup
 #
-#   Copyright (c) 2002-2008  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
 # Samizdat version
-SAMIZDAT_VERSION = '0.6.1'
+SAMIZDAT_VERSION = '0.6.2'
 
 # :main:engine.rb
 
@@ -38,12 +38,14 @@ require 'samizdat/antispam'
 
 # fix bug in standard cgi.rb
 def CGI::escapeHTML(string)
-  string.gsub(/&/n, '&amp;').gsub(/\"/n, '&quot;').gsub(/\'/n, '&apos;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;')
+  string.gsub(/&/n, '&amp;').gsub(/\"/n, '&quot;').gsub(/\'/n, '&#39;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;')
 end
 
-# add to_time() to String if it's not there
+# add to_time() to String and DateTime if it's not there
+require 'time'
+require 'date'
+
 unless ''.methods.include? 'to_time'
-  require 'time'
   class String
     def to_time
       Time.parse(self)
@@ -51,6 +53,15 @@ unless ''.methods.include? 'to_time'
   end
 end
 
+unless DateTime.strptime.methods.include? 'to_time'
+  class DateTime
+    def to_time
+      Time.parse(self.to_s)
+    end
+  end
+end
+
+# try to initialize GetText
 begin
   require 'gettext'
 
@@ -97,6 +108,7 @@ require 'samizdat/engine/dataset'
 
 require 'samizdat/engine/request'
 require 'samizdat/engine/session'
+require 'samizdat/engine/password'
 require 'samizdat/engine/preferences'
 
 require 'samizdat/engine/view'
@@ -111,3 +123,5 @@ require 'samizdat/models/focus'
 require 'samizdat/models/moderation'
 
 require 'samizdat/components/resource'
+
+require 'samizdat/plugins/loader'
