@@ -1,10 +1,10 @@
 # Samizdat engine deployment functions
 #
-#   Copyright (c) 2002-2007  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
@@ -54,8 +54,8 @@ end
 
 # helper method to load YAML data from file
 #
-def load_yaml_file(filename)
-  File.open(filename) {|f| YAML.load(f) }
+def load_yaml_file(filename, trusted = false)
+  File.open(filename) {|f| YAML.load(trusted ? f.read.untaint : f) }
 end
 
 # load and operate mapping of server prefixes to Samizdat site names
@@ -71,14 +71,12 @@ class SamizdatSites
     return unless File.readable?(SITES_MAP)
 
     @sites = {}
-    sites_raw = load_yaml_file(SITES_MAP)
+    sites_raw = load_yaml_file(SITES_MAP, true)
     sites_raw.each do |server_name, map|
       @sites[server_name] = sites_raw[server_name].keys.sort_by {|p|
         -p.size
-      }.collect {|prefix_raw|
-        # config files are always trusted
-        prefix = prefix_raw.dup.untaint
-        site = map[prefix_raw].dup.untaint
+      }.collect {|prefix|
+        site = map[prefix]
 
         # normalize prefix
         if '/' == prefix
@@ -135,7 +133,9 @@ end
 # scripts can only be reached through pre-determined locations
 #
 def site_name
-  ENV['SAMIZDAT_SITE'] or $samizdat_site_name
+  ENV['SAMIZDAT_SITE'] or (
+    $samizdat_current_request.kind_of?(Request) and
+    $samizdat_current_request.site_name)
   # or (Dir.pwd + '/config.yaml').untaint
 end
 
@@ -164,8 +164,8 @@ class SiteConfig < SimpleDelegator
   SITES_DIR = '/etc/samizdat/sites/'
 
   def initialize(site)
-    @@rdf ||= load_yaml_file(find_file(RDF, DIRS))
-    @@defaults ||= load_yaml_file(find_file(DEFAULTS, DIRS))
+    @@rdf ||= load_yaml_file(find_file(RDF, DIRS), true)
+    @@defaults ||= load_yaml_file(find_file(DEFAULTS, DIRS), true)
 
     @config = ConfigHash.new(@@rdf)
     @config.deep_update!(@@defaults)
@@ -174,24 +174,28 @@ class SiteConfig < SimpleDelegator
       if site =~ %r{/.*/config\.yaml\z} and File.readable? site
         site   # config.yaml in current directory
       else
-        SITES_DIR + site + '.yaml'
+        File.join(SITES_DIR, site + '.yaml')
       end
 
-    @config.deep_update!(load_yaml_file(site_config))
+    @config.deep_update!(load_yaml_file(site_config, true))
 
     if @config.cache and @config.cache =~ /\Adruby:/ then
       @drb = @config.cache
     end
 
+    if @config.plugins
+      @plugins = Plugins.new(@config.plugins)
+    end
+
     super @config
   end
 
-  attr_reader :drb
+  attr_reader :drb, :plugins
 
-  # pre-loaded XHTML validation configuration for Samizdat::Sanitize
+  # pre-loaded Samizdat::Sanitize object for XHTML validation
   #
   def xhtml
-    @@xhtml ||= load_yaml_file(find_file(XHTML, DIRS))
+    @@xhtml ||= Samizdat::Sanitize.new(load_yaml_file(find_file(XHTML, DIRS), true))
   end
 
   # check if all parameters necessary to send out emails are set
@@ -199,6 +203,31 @@ class SiteConfig < SimpleDelegator
   def email_enabled?
     @config['email'] and @config['email']['address'] and @config['email']['sendmail']
   end
+
+  # content directory
+  #
+  # keep its parts (document root, site content config) under control:
+  # Samizdat will write files under this directory!
+  #
+  def content_dir
+    if @content_dir.nil?
+      content = @config['site']['content']
+      content.kind_of?(String) or return @content_dir = ''
+
+      request = $samizdat_current_request
+      @content_dir = request.filename(request.content_location).untaint
+    end
+
+    @content_dir
+  end
+
+  # check if multimedia content upload is possible
+  #
+  def upload_enabled?
+    @config['site']['content'].kind_of? String and
+      File.directory?(content_dir) and
+      File.writable?(content_dir)
+  end
 end
 
 class SiteConfigSingleton
@@ -325,7 +354,7 @@ def db
   # todo: check connection timeouts
   # optimize: generate connection pool
   local_cache.fetch_or_add('database/' + site_name) do
-    db = DBI.connect(config['db']['dsn'].untaint,
+    db = DBI.connect(config['db']['dsn'],
       (ENV['USER'] or config['db']['user']),
       ENV['USER']? nil : config['db']['password'])
     begin
