@@ -1,10 +1,10 @@
 # Samizdat session management
 #
-#   Copyright (c) 2002-2007  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
@@ -22,27 +22,25 @@ class Session
   # returns cookie value on success, nil on failure
   #
   def Session.start(login, password)
-    db.transaction do |db|
-      id, = db.select_one 'SELECT id FROM Member m
-        WHERE login = ? AND password = ?', login, digest(password)
-      if id
-        cookie = random_digest(id)
-        db.do "UPDATE Member
-                  SET login_time = current_timestamp,
-                      last_time = current_timestamp,
-                      session = ?
-                WHERE id = ?", cookie, id
-        db.commit
-        return cookie
-      else
-        if config.email_enabled?
-          # check if member's email isn't confirmed yet
-          id, p = db.select_one 'SELECT id, password FROM Member
-            WHERE login = ?', login
-          raise AccountBlockedError if id and p.nil?
-        end
+    db.transaction do
+      id, p = db.select_one(
+        'SELECT id, password FROM Member WHERE login = ?', login)
+
+      if id and p.nil?
+        raise AccountBlockedError
+      elsif id.nil? or not Password.check(password, p)
         return nil
       end
+
+      cookie = random_digest(id)
+      db.do(
+        'UPDATE Member
+        SET login_time = current_timestamp,
+            last_time = current_timestamp,
+            session = ?
+        WHERE id = ?', cookie, id)
+      db.commit
+      return cookie
     end
   end
 
@@ -53,10 +51,9 @@ class Session
   # set _@login_ and _@full_name_ to 'guest'
   #
   def reset_to_guest
-    @member = nil
-    @login = 'guest'
-    @full_name = _(@login)
     @cookie = nil
+    @member = nil
+    copy_from_member_object(Member.new(nil))
   end
 
   # Usage:
@@ -70,13 +67,17 @@ class Session
       @cookie = cookie
 
       db.transaction do |db|
-        @member, @login, @full_name, @login_time = db.select_one(
-          'SELECT id, login, full_name, login_time
+        @member, @login_time = db.select_one(
+          'SELECT id, login_time
              FROM Member
             WHERE session = ?', @cookie)
 
         @member and fresh!
       end
+
+      if @member
+        copy_from_member_object(Member.cached(@member))
+      end
     end
   end
 
@@ -85,7 +86,7 @@ class Session
   # true if moderator priviledges are available to this member
   #
   def moderator?
-    @login and config['access']['moderators'].include?(@login)
+    @moderator
   end
 
   # erase session from database, remove the session cookie
@@ -111,4 +112,12 @@ class Session
       true
     end
   end
+
+  private
+
+  def copy_from_member_object(member)
+    @login = member.login
+    @full_name = member.full_name
+    @moderator = member.allowed_to?('moderate')
+  end
 end
