@@ -1,10 +1,10 @@
 # Samizdat view management class
 #
-#   Copyright (c) 2002-2007  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
@@ -13,14 +13,8 @@ require 'erb'
 
 class View
 
-  # have to untaint the data from config file before giving it to file_find
-  #
-  def template_dirs
-    @@template_dirs ||= config['templates'].collect {|d| d.untaint }
-  end
-
   def initialize(template)
-    location = find_file(template, template_dirs)
+    location = find_file(template, config['templates'])
     location or raise RuntimeError,
       "Template not found: '#{CGI.escapeHTML(template)}'"
     body = File.open(location) {|f| f.read }
