@@ -1,10 +1,10 @@
 # Samizdat RDF storage
 #
-#   Copyright (c) 2002-2008  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # see doc/rdf-storage.txt for introduction and Samizdat Squish definition;
 # see doc/storage-impl.txt for explanation of implemented algorithms
@@ -34,6 +34,7 @@ class RDF
       @map[ p.sub(/\A(\S+?)::/) { @ns[$1] } ] = m
     }
 
+    # cache parsed Squish SELECT queries
     @select_cache = Cache.new(nil, 1000)
   end
 
@@ -155,12 +156,15 @@ SELECT ?object WHERE (#{property} #{subject} ?object)}
       a[ clause[:alias] ].push(clause)
     end
 
+    statements = [] # [ { :key_node, :references, :sql, :values }, ... ]
+
     a.each do |alias_, clauses|
       subject = clauses.first[:subject]
       key_node = subject[:node]
       table = subject[:table]
 
       data = []
+      references = []
       clauses.each do |clause|
         node = clause[:object][:node]
         if new[key_node] or update[node]
@@ -169,6 +173,8 @@ SELECT ?object WHERE (#{property} #{subject} ?object)}
             q.substitute_literals(v[node])   # value
           ])
           # todo: prove that value is not nil
+
+          references.push(node) if new[node]
         end
       end
 
@@ -187,12 +193,48 @@ SELECT ?object WHERE (#{property} #{subject} ?object)}
 
       if sql
         sql, values = SquishQuery.substitute_parameters(sql, params)
-        db.do(sql, *values)
+        statements.push({
+          :key_node => key_node,
+          :references => references,
+          :sql => sql,
+          :values => values
+        })
       end
     end
 
+    run_ordered_statements(statements)
+
     return insert.collect {|node| v[node] }
   end
+
+  private
+
+  # make sure mutually referencing records are inserted in the right order
+  #
+  def run_ordered_statements(statements)
+    statements = statements.sort_by {|s| s[:references].size }
+    inserted = []
+
+    progress = true
+    until statements.empty? or not progress
+      progress = false
+
+      0.upto(statements.size - 1) do |i|
+        s = statements[i]
+        if (s[:references] - inserted).empty?
+          db.do(s[:sql], *s[:values])
+          inserted.push(s[:key_node])
+          statements.delete_at(i)
+          progress = true
+          break
+        end
+      end
+    end
+
+    progress or raise ProgrammingError,
+      "Failed to resolve mutual references of inserted resources: " +
+      statements.collect {|s| s[:sql] }.join('; ')
+  end
 end
 
 
@@ -623,7 +665,7 @@ class SqlMapper
   # undirectionally reachable from one node)
   #
   def check_graph(pattern)
-    nodes = pattern.transpose[1].uniq   # all subject nodes
+    nodes = pattern.transpose[1].uniq   # all subject nodes (fixme: nil)
 
     seen = [ nodes.shift ]
     found_more = true
