@@ -2,11 +2,11 @@
 #
 # Samizdat functional regression test
 #
-#   Copyright (c) 2002-2006  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
@@ -69,8 +69,11 @@ class TC_Robot < Test::Unit::TestCase
     end
     params = "title=#{CGI.escape(title)}&body=#{CGI.escape(body)}"
     params << "&format=#{format}" if format
-    response = post(action, params + "&preview", {"Cookie" => @@session})
-    action_token = get_action_token(response)
+    preview_response = post(action, params + "&preview", {"Cookie" => @@session})
+    if block_given?
+      yield preview_response
+    end
+    action_token = get_action_token(preview_response)
     post(action, params + "&action_token=#{action_token}&confirm", {"Cookie" => @@session})
   end
 
@@ -99,8 +102,8 @@ class TC_Robot < Test::Unit::TestCase
   end
 
   def test_01_member
-    response = post('member/create',
-      "login=#{@login}&full_name=#{@full_name}&email=#{@email}&password1=#{@password}&password2=#{@password}&submit",
+    response = post('member/create_account',
+      "login=#{@login}&email=#{@email}&password1=#{@password}&password2=#{@password}&submit",
       {'Referer' => @base.path})
     case response
     when Net::HTTPOK
@@ -110,13 +113,13 @@ class TC_Robot < Test::Unit::TestCase
       print 'test login already exists'
     when Net::HTTPFound
       assert @@session = response['set-cookie']
-      assert_equal @base.to_s, response['location']
+      assert_equal @base.to_s + 'member/profile', response['location']
 
       # check if valid session is reflected in subhead
       response = get('', {'Cookie' => @@session})
       assert_equal Net::HTTPOK, response.class
       root = parse_page(response.body)
-      assert_equal @full_name, elements(root,
+      assert_equal @login, elements(root,
         '//h:div[@id="subhead"]/h:div/h:a[1]')[0]
     else
       assert false, 'Unexpected HTTP code'
@@ -212,6 +215,7 @@ class TC_Robot < Test::Unit::TestCase
       {"Cookie" => @@session, "Referer" => @base.path + id})
     assert_equal Net::HTTPFound, response.class
     assert_equal id, response['location'].sub(@base.to_s, '')
+    sleep 5
     assert_equal Net::HTTPOK, (response = get(id)).class
     root = parse_page(response.body)
     assert_equal [': 1.00'], elements(root,
@@ -238,5 +242,25 @@ class TC_Robot < Test::Unit::TestCase
     end
   end
 
-  # todo: test skip (index.rb, resource.rb)
+  def test_06_escape_title
+    response = publish_message(%q{Test '}, '.') do |preview_response|
+      msg = REXML::XPath.first(parse_page(preview_response.body),
+        '//h:div[@id="main"]/h:div', XHTML_NS)
+      assert_equal %q{Test &#39;}, text(msg, %{//h:div[@class="box-title"]})
+    end
+    id = response['location'].sub(@base.to_s, '')
+    assert_equal Net::HTTPOK, (response = get(id)).class
+    msg = REXML::XPath.first(parse_page(response.body),
+      '//h:div[@id="main"]/h:div', XHTML_NS)
+    assert_equal %q{Test &#39;}, text(msg, %{//h:div[@class="box-title"]})
+
+    assert (response = get('')).kind_of?(Net::HTTPSuccess)
+    main = REXML::XPath.first(parse_page(response.body),
+      '//h:div[@id="main"]', XHTML_NS)
+    msg = REXML::XPath.first(main,
+      %{//h:div[@class="info"]/h:a[@href="#{@@id}"]/../..}, XHTML_NS)
+    assert_equal %q{Test &#39;}, text(msg, 'h:div[@class="title"]/h:a')
+  end
+
+  # todo: test pagination
 end
