@@ -2,11 +2,11 @@
 #
 # Samizdat test suite utility methods
 #
-#   Copyright (c) 2002-2006  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU General Public License version 2 or later.
+#   the GNU General Public License version 3 or later.
 #
 # vim: et sw=2 sts=2 ts=8 tw=0
 
@@ -37,6 +37,6 @@ def parse(html)
 end
 
 def parse_page(html)
-  xhtml = Samizdat::Sanitize.new(config.xhtml).sanitize(html, false)
+  xhtml = config.xhtml.tidy(html)
   parse(xhtml)
 end
